document.addEventListener('DOMContentLoaded', function() {
    // 初期設定
    var aggregationTarget = clickTrackerData.aggregation_target;
    var aggregationPeriod = clickTrackerData.aggregation_period;
    var selectedTab = clickTrackerData.selected_tab;
    var groupPresets = clickTrackerData.group_presets;

    var aggregationTargetSelect = document.getElementById('aggregation_target');
    var aggregationPeriodSelect = document.getElementById('aggregation_period');
    var tabs = document.querySelectorAll('.tab-item');
    var resultsTable = document.getElementById('results_table');

    // プルダウンのイベントリスナー
    aggregationTargetSelect.addEventListener('change', function() {
        aggregationTarget = this.value;
        fetchAggregationResults();
    });

    aggregationPeriodSelect.addEventListener('change', function() {
        aggregationPeriod = this.value;
        fetchAggregationResults();
    });

    // タブのクリックイベント
    tabs.forEach(function(tab) {
        tab.addEventListener('click', function() {
            // タブの選択状態を更新
            tabs.forEach(function(t) { t.classList.remove('active'); });
            this.classList.add('active');
            selectedTab = this.getAttribute('data-tab');
            fetchAggregationResults();
        });
    });

    // 集計結果を取得して表示
    function fetchAggregationResults() {
        var data = {
            action: 'click_tracker_get_aggregation_results',
            security: clickTrackerData.security,
            aggregation_target: aggregationTarget,
            aggregation_period: aggregationPeriod,
            selected_tab: selectedTab
        };

        var xhr = new XMLHttpRequest();
        xhr.open('POST', clickTrackerData.ajax_url, true);
        xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded; charset=UTF-8');
        xhr.onload = function() {
            if (xhr.status === 200) {
                var response = JSON.parse(xhr.responseText);
                if (response.success) {
                    renderResultsTable(response.data);
                } else {
                    alert('データの取得に失敗しました。');
                }
            } else {
                alert('データの取得に失敗しました。');
            }
        };
        xhr.send(encodeFormData(data));
    }

    // 結果テーブルのレンダリング
    function renderResultsTable(data) {
        var dataToDisplay = data.data_to_display;
        var aggregationTarget = data.aggregation_target;

        var html = '<table class="widefat"><thead><tr><th>タグ</th>';
        if (aggregationTarget == 'tags_urls') {
            html += '<th>URL</th>';
        }
        html += '<th>クリック数</th><th>操作</th></tr></thead><tbody>';

        dataToDisplay.forEach(function(row) {
            html += '<tr>';
            html += '<td><a href="#" class="tag-link" data-tag="' + row.tag + '">' + row.tag + '</a></td>';
            if (aggregationTarget == 'tags_urls') {
                html += '<td>' + (row.url ? row.url : '') + '</td>';
            }
            html += '<td>' + row.count + '</td>';
            html += '<td><form method="post" style="display:inline;">';
            html += '<input type="hidden" name="reset_tag_data" value="' + row.tag + '" />';
            html += '<button type="submit" class="button reset-button">初期化</button>';
            html += '</form></td>';
            html += '</tr>';
        });

        html += '</tbody></table>';

        resultsTable.innerHTML = html;

        // 新しく生成されたタグリンクにイベントリスナーを追加
        var tagLinks = document.querySelectorAll('.tag-link');
        tagLinks.forEach(function(tagLink) {
            tagLink.addEventListener('click', function(e) {
                e.preventDefault();
                var tag = tagLink.getAttribute('data-tag');
                openGraphModal(tag);
            });
        });
    }

    // 初回のデータ取得
    fetchAggregationResults();

    // フォームの送信を防止（リセットボタンのため）
    document.querySelectorAll('form').forEach(function(form) {
        form.addEventListener('submit', function(e) {
            if (!confirm('本当にリセットしますか？')) {
                e.preventDefault();
            }
        });
    });

    // 以下、グラフ表示に関するコード（以前と同様）
    var graphModal = document.getElementById('graph_modal');
    var closeGraph = document.getElementById('close_graph');
    var graphContent = document.getElementById('graph_content');
    var graphTitle = document.getElementById('graph_title');
    var graphCanvas = document.getElementById('graph_canvas');
    var graphTypeSelect = document.getElementById('graph_type');
    var graphPeriodSelect = document.getElementById('graph_period');
    var chartInstance = null;

    closeGraph.addEventListener('click', function() {
        graphModal.style.display = 'none';
    });

    // モーダル背景をクリックしたときに閉じる処理
    graphModal.addEventListener('click', function() {
        graphModal.style.display = 'none';
    });

    // モーダルコンテンツ内のクリックイベントが背景に伝播しないように設定
    graphContent.addEventListener('click', function(e) {
        e.stopPropagation();
    });

    function openGraphModal(tag) {
        graphTitle.textContent = 'タグ: ' + tag;

        var graphType = localStorage.getItem('click_tracker_graph_type') || 'bar';
        var graphPeriod = localStorage.getItem('click_tracker_graph_period') || 'today';
        graphTypeSelect.value = graphType;
        graphPeriodSelect.value = graphPeriod;

        fetchGraphData(tag, graphPeriod, graphType);
        graphModal.style.display = 'block';
    }

    function fetchGraphData(tag, period, graphType) {
        var data = {
            action: 'click_tracker_get_graph_data',
            security: clickTrackerData.security,
            tag: tag,
            period: period
        };

        var xhr = new XMLHttpRequest();
        xhr.open('POST', clickTrackerData.ajax_url, true);
        xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded; charset=UTF-8');
        xhr.onload = function() {
            if (xhr.status === 200) {
                var response = JSON.parse(xhr.responseText);
                if (response.success) {
                    renderGraph(response.data, graphType);
                } else {
                    alert('データの取得に失敗しました。');
                }
            } else {
                alert('データの取得に失敗しました。');
            }
        };
        xhr.send(encodeFormData(data));
    }

    function encodeFormData(data) {
        var pairs = [];
        for (var name in data) {
            if (!data.hasOwnProperty(name)) continue;
            pairs.push(encodeURIComponent(name) + '=' + encodeURIComponent(data[name]));
        }
        return pairs.join('&');
    }

    function renderGraph(data, graphType) {
        var ctx = graphCanvas.getContext('2d');
        if (chartInstance) {
            chartInstance.destroy();
        }
        chartInstance = new Chart(ctx, {
            type: graphType,
            data: data,
            options: {}
        });
    }

    graphTypeSelect.addEventListener('change', function() {
        var graphType = this.value;
        var tag = graphTitle.textContent.replace('タグ: ', '');
        var period = graphPeriodSelect.value;
        localStorage.setItem('click_tracker_graph_type', graphType);
        fetchGraphData(tag, period, graphType);
    });

    graphPeriodSelect.addEventListener('change', function() {
        var period = this.value;
        var tag = graphTitle.textContent.replace('タグ: ', '');
        var graphType = graphTypeSelect.value;
        localStorage.setItem('click_tracker_graph_period', period);
        fetchGraphData(tag, period, graphType);
    });
});
