<?php
if (!defined('ABSPATH')) {
    exit;
}

// ユーザーの選択を取得する関数
function click_tracker_get_user_selection() {
    $aggregation_target = isset($_GET['aggregation_target']) ? $_GET['aggregation_target'] : (isset($_COOKIE['click_tracker_aggregation_target']) ? $_COOKIE['click_tracker_aggregation_target'] : 'tags');
    $aggregation_period = isset($_GET['aggregation_period']) ? $_GET['aggregation_period'] : (isset($_COOKIE['click_tracker_aggregation_period']) ? $_COOKIE['click_tracker_aggregation_period'] : 'today');
    $selected_tab = isset($_GET['selected_tab']) ? $_GET['selected_tab'] : (isset($_COOKIE['click_tracker_selected_tab']) ? $_COOKIE['click_tracker_selected_tab'] : 'all');

    return array(
        'aggregation_target' => $aggregation_target,
        'aggregation_period' => $aggregation_period,
        'selected_tab' => $selected_tab,
    );
}

// クッキーを設定する関数
function click_tracker_set_cookies() {
    // ユーザーの選択を取得
    $selection = click_tracker_get_user_selection();
    $aggregation_target = $selection['aggregation_target'];
    $aggregation_period = $selection['aggregation_period'];
    $selected_tab = $selection['selected_tab'];

    // ヘッダーが送信されていない場合にクッキーを設定
    if (!headers_sent()) {
        setcookie('click_tracker_aggregation_target', $aggregation_target, time() + 3600 * 24 * 30, COOKIEPATH, COOKIE_DOMAIN);
        setcookie('click_tracker_aggregation_period', $aggregation_period, time() + 3600 * 24 * 30, COOKIEPATH, COOKIE_DOMAIN);
        setcookie('click_tracker_selected_tab', $selected_tab, time() + 3600 * 24 * 30, COOKIEPATH, COOKIE_DOMAIN);
    }
}
// admin_init フックでクッキーを設定
add_action('admin_init', 'click_tracker_set_cookies');

// ユーザーの選択を取得
$selection = click_tracker_get_user_selection();
$aggregation_target = $selection['aggregation_target'];
$aggregation_period = $selection['aggregation_period'];
$selected_tab = $selection['selected_tab'];

// リセットアクションの処理
if (isset($_POST['reset_all_data']) && check_admin_referer('click_tracker_reset_all', 'click_tracker_reset_all_nonce')) {
    global $wpdb;
    $table_name = $wpdb->prefix . 'click_tracker';
    $wpdb->query("TRUNCATE TABLE $table_name");
    echo '<div class="notice notice-success"><p>全てのデータがリセットされました。</p></div>';
}

if (isset($_POST['reset_tag_data']) && check_admin_referer('click_tracker_reset_tag', 'click_tracker_reset_tag_nonce')) {
    $tag = sanitize_text_field($_POST['reset_tag_data']);
    global $wpdb;
    $table_name = $wpdb->prefix . 'click_tracker';
    $wpdb->delete($table_name, array('tag' => $tag));
    echo '<div class="notice notice-success"><p>タグ "' . esc_html($tag) . '" のデータがリセットされました。</p></div>';
}

// 設定の取得
$settings = get_option('click_tracker_settings', array());
$group_presets = isset($settings['group_presets']) ? $settings['group_presets'] : array();

// 必要なデータをJavaScriptに渡す
wp_localize_script('click-tracker-admin', 'clickTrackerData', array(
    'ajax_url' => admin_url('admin-ajax.php'),
    'security' => wp_create_nonce('click_tracker_nonce'),
    'reset_tag_nonce' => wp_create_nonce('click_tracker_reset_tag'),
    'aggregation_target' => $aggregation_target,
    'aggregation_period' => $aggregation_period,
    'selected_tab' => $selected_tab,
    'group_presets' => $group_presets,
));
?>
<div class="wrap">
    <h1>Click Tracker 集計結果</h1>
    <div id="aggregation_controls" class="aggregation-controls">
        <!-- フォームを復活させ、更新ボタンを追加 -->
        <label for="aggregation_target">表示対象:</label>
        <select id="aggregation_target" name="aggregation_target" class="aggregation-select">
            <option value="tags" <?php selected($aggregation_target, 'tags'); ?>>タグ</option>
            <option value="tags_urls" <?php selected($aggregation_target, 'tags_urls'); ?>>タグとURL</option>
        </select>

        <label for="aggregation_period">集計期間:</label>
        <select id="aggregation_period" name="aggregation_period" class="aggregation-select">
            <option value="today" <?php selected($aggregation_period, 'today'); ?>>今日</option>
            <option value="yesterday" <?php selected($aggregation_period, 'yesterday'); ?>>昨日</option>
            <option value="7_days" <?php selected($aggregation_period, '7_days'); ?>>過去7日間</option>
            <option value="30_days" <?php selected($aggregation_period, '30_days'); ?>>過去30日間</option>
            <option value="12_months" <?php selected($aggregation_period, '12_months'); ?>>過去12か月間</option>
        </select>

        <!-- 更新ボタンを復活 -->
        <button type="button" class="button button-primary" id="update_results">更新</button>
    </div>

    <!-- タブのHTML -->
    <div id="tabs" class="tabs-container">
        <button class="tab <?php echo $selected_tab == 'all' ? 'active' : ''; ?>" data-group="all">全て</button>
        <?php foreach ($group_presets as $group_preset): ?>
            <button class="tab <?php echo $selected_tab == $group_preset ? 'active' : ''; ?>" data-group="<?php echo esc_attr($group_preset); ?>"><?php echo esc_html($group_preset); ?></button>
        <?php endforeach; ?>
    </div>

    <div id="results_table">
        <!-- 結果はJavaScriptで動的に挿入 -->
    </div>

    <form method="post">
        <?php wp_nonce_field('click_tracker_reset_all', 'click_tracker_reset_all_nonce'); ?>
        <button type="submit" class="button reset-button" name="reset_all_data">全データをリセット</button>
    </form>
</div>

<!-- グラフモーダルウィンドウ -->
<div id="graph_modal" class="graph-modal" style="display:none;">
    <div id="graph_content" class="graph-content">
        <span id="close_graph" class="close-graph">&times;</span>
        <h2 id="graph_title"></h2>
        <canvas id="graph_canvas"></canvas>
        <div class="graph-controls">
            <div class="control-group">
                <label for="graph_type">グラフの種類:</label>
                <select id="graph_type">
                    <option value="bar">棒グラフ</option>
                    <option value="line">折れ線グラフ</option>
                </select>
            </div>
            <div class="control-group">
                <label for="graph_period">集計期間:</label>
                <select id="graph_period">
                    <option value="today">今日</option>
                    <option value="yesterday">昨日</option>
                    <option value="7_days">過去7日間</option>
                    <option value="30_days">過去30日間</option>
                    <option value="12_months">過去12か月間</option>
                </select>
            </div>
        </div>
    </div>
</div>

<!-- JavaScriptコード -->
<script>
document.addEventListener('DOMContentLoaded', function() {
    // 初期設定
    var aggregationTarget = clickTrackerData.aggregation_target;
    var aggregationPeriod = clickTrackerData.aggregation_period;
    var selectedTab = clickTrackerData.selected_tab;
    var groupPresets = clickTrackerData.group_presets;

    var aggregationTargetSelect = document.getElementById('aggregation_target');
    var aggregationPeriodSelect = document.getElementById('aggregation_period');
    var updateButton = document.getElementById('update_results');
    var tabs = document.querySelectorAll('.tab');
    var resultsTable = document.getElementById('results_table');

    // クッキーを設定する関数
    function setCookie(name, value, days) {
        var expires = "";
        if (days) {
            var date = new Date();
            date.setTime(date.getTime() + (days*24*60*60*1000));
            expires = "; expires=" + date.toUTCString();
        }
        document.cookie = name + "=" + encodeURIComponent(value) + expires + "; path=/";
    }

    // セレクトボックスの変更イベントリスナーを追加（自動更新）
    aggregationTargetSelect.addEventListener('change', function() {
        aggregationTarget = this.value;
        setCookie('click_tracker_aggregation_target', aggregationTarget, 30);
        fetchAggregationResults();
    });

    aggregationPeriodSelect.addEventListener('change', function() {
        aggregationPeriod = this.value;
        setCookie('click_tracker_aggregation_period', aggregationPeriod, 30);
        fetchAggregationResults();
    });

    // タブのクリックイベント
    tabs.forEach(function(tab) {
        tab.addEventListener('click', function() {
            // タブの選択状態を更新
            tabs.forEach(function(t) { t.classList.remove('active'); });
            this.classList.add('active');
            selectedTab = this.getAttribute('data-group');
            setCookie('click_tracker_selected_tab', selectedTab, 30);
            fetchAggregationResults();
        });
    });

    // 更新ボタンのイベントリスナー（手動更新）
    updateButton.addEventListener('click', function() {
        fetchAggregationResults();
    });

    // 集計結果を取得して表示
    function fetchAggregationResults() {
        var data = {
            action: 'click_tracker_get_aggregation_results',
            security: clickTrackerData.security,
            aggregation_target: aggregationTarget,
            aggregation_period: aggregationPeriod,
            selected_tab: selectedTab
        };

        var xhr = new XMLHttpRequest();
        xhr.open('POST', clickTrackerData.ajax_url, true);
        xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded; charset=UTF-8');
        xhr.onload = function() {
            if (xhr.status === 200) {
                var response = JSON.parse(xhr.responseText);
                if (response.success) {
                    renderResultsTable(response.data);

                    // aggregationTarget の値に応じて幅を変更
                    if (aggregationTarget === 'tags') {
                        resultsTable.style.width = '50%';
                    } else if (aggregationTarget === 'tags_urls') {
                        resultsTable.style.width = '70%';
                    }

                    // ブラウザの幅が1024px未満の場合、幅を100%に設定
                    if (window.innerWidth < 1024) {
                        resultsTable.style.width = '100%';
                    }
                } else {
                    alert('データの取得に失敗しました。');
                }
            } else {
                alert('データの取得に失敗しました。');
            }
        };
        xhr.send(encodeFormData(data));
    }

    // 結果テーブルのレンダリング
    function renderResultsTable(data) {
        var dataToDisplay = data.data_to_display;
        var aggregationTarget = data.aggregation_target;

        var html = '<table class="widefat"><thead><tr><th>タグ</th>';
        if (aggregationTarget == 'tags_urls') {
            html += '<th>URL</th>';
        }
        html += '<th>クリック数</th><th>操作</th></tr></thead><tbody>';

        dataToDisplay.forEach(function(row) {
            html += '<tr>';
            html += '<td><a href="#" class="tag-link" data-tag="' + row.tag + '">' + row.tag + '</a></td>';
            if (aggregationTarget == 'tags_urls') {
                html += '<td>' + (row.url ? row.url : '') + '</td>';
            }
            html += '<td>' + row.count + '</td>';
            html += '<td><form method="post" style="display:inline;">';
            html += '<input type="hidden" name="click_tracker_reset_tag_nonce" value="' + clickTrackerData.reset_tag_nonce + '">';
            html += '<input type="hidden" name="reset_tag_data" value="' + row.tag + '" />';
            html += '<button type="submit" class="button reset-button">リセット</button>';
            html += '</form></td>';
            html += '</tr>';
        });

        html += '</tbody></table>';

        resultsTable.innerHTML = html;

        // 新しく生成されたタグリンクにイベントリスナーを追加
        var tagLinks = document.querySelectorAll('.tag-link');
        tagLinks.forEach(function(tagLink) {
            tagLink.addEventListener('click', function(e) {
                e.preventDefault();
                var tag = tagLink.getAttribute('data-tag');
                openGraphModal(tag);
            });
        });
    }

    // 初回のデータ取得
    fetchAggregationResults();

    // ウィンドウのリサイズイベントを監視して幅を調整
    window.addEventListener('resize', function() {
        if (window.innerWidth < 1024) {
            resultsTable.style.width = '100%';
        } else {
            if (aggregationTarget === 'tags') {
                resultsTable.style.width = '50%';
            } else if (aggregationTarget === 'tags_urls') {
                resultsTable.style.width = '70%';
            }
        }
    });

    // リセットボタンの確認ダイアログ
    document.addEventListener('submit', function(e) {
        if (e.target.matches('form')) {
            if (!confirm('本当にリセットしますか？')) {
                e.preventDefault();
            }
        }
    });

    // グラフ表示に関するコード
    var graphModal = document.getElementById('graph_modal');
    var closeGraph = document.getElementById('close_graph');
    var graphContent = document.getElementById('graph_content');
    var graphTitle = document.getElementById('graph_title');
    var graphCanvas = document.getElementById('graph_canvas');
    var graphTypeSelect = document.getElementById('graph_type');
    var graphPeriodSelect = document.getElementById('graph_period');
    var chartInstance = null;

    closeGraph.addEventListener('click', function() {
        graphModal.style.display = 'none';
    });

    // モーダル背景をクリックしたときに閉じる処理
    graphModal.addEventListener('click', function() {
        graphModal.style.display = 'none';
    });

    // モーダルコンテンツ内のクリックイベントが背景に伝播しないように設定
    graphContent.addEventListener('click', function(e) {
        e.stopPropagation();
    });

    function openGraphModal(tag) {
        graphTitle.textContent = 'タグ: ' + tag;

        var graphType = localStorage.getItem('click_tracker_graph_type') || 'bar';
        var graphPeriod = localStorage.getItem('click_tracker_graph_period') || 'today';
        graphTypeSelect.value = graphType;
        graphPeriodSelect.value = graphPeriod;

        fetchGraphData(tag, graphPeriod, graphType);
        graphModal.style.display = 'block';
    }

    function fetchGraphData(tag, period, graphType) {
        var data = {
            action: 'click_tracker_get_graph_data',
            security: clickTrackerData.security,
            tag: tag,
            period: period
        };

        var xhr = new XMLHttpRequest();
        xhr.open('POST', clickTrackerData.ajax_url, true);
        xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded; charset=UTF-8');
        xhr.onload = function() {
            if (xhr.status === 200) {
                var response = JSON.parse(xhr.responseText);
                if (response.success) {
                    renderGraph(response.data, graphType);
                } else {
                    alert('データの取得に失敗しました。');
                }
            } else {
                alert('データの取得に失敗しました。');
            }
        };
        xhr.send(encodeFormData(data));
    }

    function encodeFormData(data) {
        var pairs = [];
        for (var name in data) {
            if (!data.hasOwnProperty(name)) continue;
            pairs.push(encodeURIComponent(name) + '=' + encodeURIComponent(data[name]));
        }
        return pairs.join('&');
    }

    function renderGraph(data, graphType) {
        var ctx = graphCanvas.getContext('2d');
        if (chartInstance) {
            chartInstance.destroy();
        }
        chartInstance = new Chart(ctx, {
            type: graphType,
            data: data,
            options: {}
        });
    }

    graphTypeSelect.addEventListener('change', function() {
        var graphType = this.value;
        var tag = graphTitle.textContent.replace('タグ: ', '');
        var period = graphPeriodSelect.value;
        localStorage.setItem('click_tracker_graph_type', graphType);
        fetchGraphData(tag, period, graphType);
    });

    graphPeriodSelect.addEventListener('change', function() {
        var period = this.value;
        var tag = graphTitle.textContent.replace('タグ: ', '');
        var graphType = graphTypeSelect.value;
        localStorage.setItem('click_tracker_graph_period', period);
        fetchGraphData(tag, period, graphType);
    });
});
</script>

<!-- スタイルシート -->
<style>
/* タブのスタイルを更新 */
.tab.active {
    background-color: #0073aa;
    color: #fff;
}
.tab {
    padding: 7px 20px;
    margin-right: 5px;
    background-color: #f1f1f1;
    border: none;
    cursor: pointer;
    border-radius: 3px;
    transition: background-color 0.3s;
}

.tab:hover {
    background-color: #e2e2e2;
}

/* #aggregation_targetと#aggregation_periodのマージンを追加 */
#aggregation_target {
    margin-right: 10px;
}

#aggregation_period {
    margin-right: 5px;
}

/* #results_tableのマージンを追加 */
#results_table {
    margin-top: 10px;
    margin-bottom: 10px;
    width: 50%; /* 初期幅を設定。JavaScriptで動的に変更 */
}

/* ブラウザの幅が1024ピクセル未満の場合にwidthを100%に設定 */
@media screen and (max-width: 1024px) {
    #results_table {
        width: 100% !important;
    }
}

/* グラフモーダルのスタイル */
.graph-modal {
    display: none;
    position: fixed;
    z-index: 9999;
    left: 0;
    top: 0;
    width: 100%;
    height: 100%;
    overflow: auto;
    /* 背景色を設定してクリックを検知できるように */
    background-color: rgba(0, 0, 0, 0.4);
}

.graph-content {
    background-color: #fff;
    margin: 5% auto;
    padding: 20px;
    border: 1px solid #888;
    width: 80%;
    max-width: 800px;
    position: relative;
}

.close-graph {
    color: #aaa;
    float: right;
    font-size: 28px;
    font-weight: bold;
}

.close-graph:hover,
.close-graph:focus {
    color: black;
    text-decoration: none;
    cursor: pointer;
}

.graph-controls {
    margin-top: 20px;
}

.graph-controls .control-group {
    display: inline-block;
    margin-right: 20px;
}
</style>
