<?php
if (!defined('ABSPATH')) {
    exit;
}

if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['click_tracker_settings_nonce'])) {
    if (!wp_verify_nonce($_POST['click_tracker_settings_nonce'], 'click_tracker_save_settings')) {
        echo '<div class="notice notice-error"><p>セキュリティチェックに失敗しました。</p></div>';
        exit;
    }

    $settings = get_option('click_tracker_settings', array());

    // クリックを追跡するクラス
    if (isset($_POST['tracking_classes']) && is_array($_POST['tracking_classes'])) {
        $tracking_classes = array();
        foreach ($_POST['tracking_classes'] as $tracking_class) {
            $class_name = sanitize_text_field($tracking_class['class_name']);
            $tag = sanitize_text_field($tracking_class['tag']);
            $group_name = sanitize_text_field($tracking_class['group_name']);

            if ($class_name && $tag) {
                $tracking_classes[] = array(
                    'class_name' => $class_name,
                    'tag' => $tag,
                    'group_name' => $group_name,
                );
            }
        }
        $settings['tracking_classes'] = $tracking_classes;
    }

    // グループ名のプリセット
    if (isset($_POST['group_presets']) && is_array($_POST['group_presets'])) {
        $group_presets = array();
        foreach ($_POST['group_presets'] as $group_name) {
            $group_name = sanitize_text_field($group_name);
            if ($group_name) {
                $group_presets[] = $group_name;
            }
        }
        $settings['group_presets'] = $group_presets;
    }

    // 除外するIPアドレス
    if (isset($_POST['exclude_ips'])) {
        $exclude_ips_raw = explode(',', $_POST['exclude_ips']);
        $exclude_ips = array();
        foreach ($exclude_ips_raw as $ip) {
            $ip = trim($ip);
            if (filter_var($ip, FILTER_VALIDATE_IP)) {
                $exclude_ips[] = $ip;
            }
        }
        $settings['exclude_ips'] = $exclude_ips;
    }

    // 管理者のクリック追跡
    $settings['track_admin'] = isset($_POST['track_admin']) ? true : false;

    update_option('click_tracker_settings', $settings);
    echo '<div class="notice notice-success"><p>設定が保存されました。</p></div>';
}

$settings = get_option('click_tracker_settings', array());
$tracking_classes = isset($settings['tracking_classes']) ? $settings['tracking_classes'] : array();
$group_presets = isset($settings['group_presets']) ? $settings['group_presets'] : array();
$exclude_ips = isset($settings['exclude_ips']) ? implode(', ', $settings['exclude_ips']) : '';
$track_admin = isset($settings['track_admin']) ? $settings['track_admin'] : false;
?>
<div class="wrap">
    <h1>Click Tracker 設定</h1>
    <form method="post">
        <?php wp_nonce_field('click_tracker_save_settings', 'click_tracker_settings_nonce'); ?>

        <h2>クリックを追跡するクラス</h2>
        <table id="tracking-classes-table" class="widefat">
            <thead>
                <tr>
                    <th>クラス名</th>
                    <th>タグ</th>
                    <th>グループ</th>
                    <th>操作</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($tracking_classes as $index => $tracking_class): ?>
                <tr>
                    <td><input type="text" name="tracking_classes[<?php echo $index; ?>][class_name]" value="<?php echo esc_attr($tracking_class['class_name']); ?>" required /></td>
                    <td><input type="text" name="tracking_classes[<?php echo $index; ?>][tag]" value="<?php echo esc_attr($tracking_class['tag']); ?>" required /></td>
                    <td>
                        <select name="tracking_classes[<?php echo $index; ?>][group_name]">
                            <option value="">（なし）</option>
                            <?php foreach ($group_presets as $group_preset): ?>
                            <option value="<?php echo esc_attr($group_preset); ?>" <?php selected($tracking_class['group_name'], $group_preset); ?>><?php echo esc_html($group_preset); ?></option>
                            <?php endforeach; ?>
                        </select>
                    </td>
                    <td><button type="button" class="button remove-class">削除</button></td>
                </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
        <button type="button" class="button" id="add-class">新しい行を追加</button>
        <br/><br/>
        <button type="submit" class="button button-primary">設定を保存</button>

        <hr/>

        <h2>グループ名のプリセット</h2>
        <table id="group-presets-table" class="widefat">
            <thead>
                <tr>
                    <th>グループ名</th>
                    <th>操作</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($group_presets as $index => $group_preset): ?>
                <tr>
                    <td><input type="text" name="group_presets[]" value="<?php echo esc_attr($group_preset); ?>" required /></td>
                    <td><button type="button" class="button remove-group">削除</button></td>
                </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
        <button type="button" class="button" id="add-group">新しい行を追加</button>
        <br/><br/>
        <button type="submit" class="button button-primary">設定を保存</button>

        <hr/>

        <h2>除外するIPアドレス</h2>
        <p>クリックを追跡しないIPアドレスをカンマ区切りで入力してください。</p>
        <textarea name="exclude_ips" rows="3" cols="50"><?php echo esc_textarea($exclude_ips); ?></textarea>

        <hr/>

        <h2>管理者のクリックを追跡</h2>
        <label>
            <input type="checkbox" name="track_admin" <?php checked($track_admin, true); ?> />
            管理者のクリックを追跡する
        </label>

        <br/><br/>
        <button type="submit" class="button button-primary">設定を保存</button>
    </form>
</div>

<script>
document.addEventListener('DOMContentLoaded', function() {
    // トラッキングクラスの追加
    document.getElementById('add-class').addEventListener('click', function() {
        var table = document.getElementById('tracking-classes-table').getElementsByTagName('tbody')[0];
        var newRow = table.insertRow();
        var index = table.rows.length - 1;

        // グループ名のオプションを取得
        var groupOptions = '<option value="">（なし）</option>';
        <?php
        $group_presets_js = json_encode($group_presets);
        ?>
        var groupPresets = <?php echo $group_presets_js; ?>;
        groupPresets.forEach(function(group) {
            if (group.trim().length > 0) {
                groupOptions += '<option value="' + group + '">' + group + '</option>';
            }
        });

        newRow.innerHTML = `
            <td><input type="text" name="tracking_classes[${index}][class_name]" required /></td>
            <td><input type="text" name="tracking_classes[${index}][tag]" required /></td>
            <td>
                <select name="tracking_classes[${index}][group_name]">
                    ${groupOptions}
                </select>
            </td>
            <td><button type="button" class="button remove-class">削除</button></td>
        `;
    });

    // トラッキングクラスの削除
    document.getElementById('tracking-classes-table').addEventListener('click', function(e) {
        if (e.target && e.target.classList.contains('remove-class')) {
            var row = e.target.closest('tr');
            row.parentNode.removeChild(row);
        }
    });

    // グループ名の追加
    document.getElementById('add-group').addEventListener('click', function() {
        var table = document.getElementById('group-presets-table').getElementsByTagName('tbody')[0];
        var newRow = table.insertRow();

        newRow.innerHTML = `
            <td><input type="text" name="group_presets[]" required /></td>
            <td><button type="button" class="button remove-group">削除</button></td>
        `;
    });

    // グループ名の削除
    document.getElementById('group-presets-table').addEventListener('click', function(e) {
        if (e.target && e.target.classList.contains('remove-group')) {
            var row = e.target.closest('tr');
            row.parentNode.removeChild(row);
        }
    });
});
</script>
<!-- スタイルシート -->
<style>
/* #tracking-classes-tableと#group-presets-tableにマージンを追加 */
#tracking-classes-table,
#group-presets-table {
    margin-bottom: 10px;
    width: 50%;
}
@media (max-width: 1024px){
#tracking-classes-table,
#group-presets-table {
    width: 100%;
}

}

</style>
